@echo off
cls

REM *****************************************************************
REM **
REM **  Usage:  filename.bat "Title of video" "InputSource.ext" "InputSubtitles.ext"
REM **
REM *****************************************************************


REM ** 
REM ** Configuration here...
REM ** 


REM ** Note: if VideoToMKV supplied a bitrate, then use that, otherwise use the defaults here
IF "%V2MKV_VBitrate%" == "" ( SET V2MKV_VBitrate=1400k )
IF "%V2MKV_ABitrate%" == "" ( SET V2MKV_ABitrate=512k )
SET FFApp=ffmpeg.exe
SET FFVideo=-vcodec libxvid -b %V2MKV_VBitrate% -r 23.97 -g 250 -coder 0 -level 13
SET FFAudio=-acodec ac3 -ab %V2MKV_ABitrate% -ar 48000 -ac 6
REM ** Note: you can use this to limit the duration of transcoding for testing/debugging purposes
REM SET FFMaxTime=-t 60
SET FFHeaderInfo=-title %1 -author "Peter Souza IV" -copyright "VideoToMKV" -comment "Encoded with ffmpeg."

SET MKVApp="mkvmerge.exe"
REM ** Note: if MKVMerge utilities have been installed, use that version instead of the one supplied with VideoToMKV
IF EXIST "%ProgramFiles%\MKVtoolnix\mkvmerge.exe" ( SET MKVApp="%ProgramFiles%\MKVtoolnix\mkvmerge.exe" )
IF EXIST "%ProgramFiles(x86)%\MKVtoolnix\mkvmerge.exe" ( SET MKVApp="%ProgramFiles(x86)%\MKVtoolnix\mkvmerge.exe" )
SET MKVlang=eng
REM ** Note: MKVLangList, MKVSubList, and MKVSubOrder are set from VideoToMKV directly


REM ** 
REM ** Conversion process here...
REM ** 


REM ** Convert original video/audio file to compressed video/audio format, splitting into seperate streams
START "FFMPEG Decoder" /B /LOW /WAIT %FFApp% %FFMaxTime% -y -i %2 %FFVideo% %FFHeaderInfo% -an (temp).avi
START "FFMPEG Decoder" /B /LOW /WAIT %FFApp% %FFMaxTime% -y -i %2 %FFAudio% %FFHeaderInfo% -vn (temp).ac3

REM ** Determine if we're muxing subtitle streams
IF "%MKVSubList%" == "" ( GOTO NoSubs )
IF EXIST %3 GOTO DoSubs
GOTO NoSubs

:NoSubs
REM ** Stuff compressed video/audio file into an MKV container without subtitles
START "MKVMerge Encoder" /B /LOW /WAIT %MKVApp% -o %1.mkv --language 0:%MKVlang% -a 0 -D -S "(temp).ac3" --language 0:%MKVlang% -d 0 -A -S "(temp).avi" --track-order 1:0,0:0
GOTO CleanUp

:DoSubs
REM ** Stuff compressed video/audio file into an MKV container with subtitles
ECHO ON
START "MKVMerge Encoder" /B /LOW /WAIT %MKVApp% -o %1.mkv --language 0:%MKVlang% -a 0 -D -S "(temp).ac3" --language 0:%MKVlang% -d 0 -A -S "(temp).avi" %MKVLangList% %MKVSubList% -D -A %3 --track-order 1:0,0:0%MKVSubOrder%
@ECHO OFF
PAUSE

:CleanUp
REM ** Delete temporary video and audio files
DEL (temp).ac3
DEL (temp).avi
